from .AreaChart import AreaChart
from .BarChart import BarChart
from .ChartContainer import ChartContainer
from .ChartLegend import ChartLegend
from .ChartTooltip import ChartTooltip

__all__ = [
    "AreaChart",
    "BarChart",
    "ChartContainer",
    "ChartLegend",
    "ChartTooltip"
]


from pathlib import Path
import sys

__version__ = "1.0.1"

# Get the directory of this package
_current_dir = Path(__file__).parent

# Define the JavaScript distribution files for Dash
_js_dist = [
    {
        "relative_package_path": "dashkit_shadcn.js",
        "namespace": "dashkit_shadcn",
        "async": False
    }
]

# For development/debugging, also include the proptypes
_js_dist.append({
    "relative_package_path": "proptypes.js",
    "dev_only": True,
    "namespace": "dashkit_shadcn",
    "async": False
})

# Import the component classes and set _js_dist directly on them
from .AreaChart import AreaChart
from .BarChart import BarChart
from .ChartContainer import ChartContainer
from .ChartLegend import ChartLegend
from .ChartTooltip import ChartTooltip

# Set the _js_dist attribute on each component class so Dash can find them
AreaChart._js_dist = _js_dist
BarChart._js_dist = _js_dist
ChartContainer._js_dist = _js_dist
ChartLegend._js_dist = _js_dist
ChartTooltip._js_dist = _js_dist

# Export components so they're available at module level
__all__ = [
    "AreaChart",
    "BarChart", 
    "ChartContainer",
    "ChartLegend",
    "ChartTooltip"
]


# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class ChartContainer(Component):
    """A ChartContainer component.


Keyword arguments:

- children (dict; required)

    `children` is a dict with keys:

    - type (string; required)

    - props (boolean | number | string | dict | list; required)

    - key (string; required)

- id (string; optional)

- className (string; optional)

- config (dict; required)

    `config` is a dict with strings as keys and values of type dict
    with keys:

    - label (a list of or a singular dash component, string or number; optional)

    - icon (boolean | number | string | dict | list; optional)

    - color (string; optional)

    - theme (dict; optional)

        `theme` is a dict with keys:

        - light (string; required)

        - dark (string; required)

- key (string | number; optional)

- ref (string; optional):
    Allows getting a ref to the component instance. Once the component
    unmounts, React will set `ref.current` to `None` (or call the ref
    with `None` if you passed a callback ref). @,see,,{@link
    ,https://react.dev/learn/referencing-values-with-refs#refs-and-the-dom
    React Docs,}."""
    _children_props = ['config{}.label']
    _base_nodes = ['children']
    _namespace = 'dashkit_shadcn'
    _type = 'ChartContainer'
    ConfigTheme = TypedDict(
        "ConfigTheme",
            {
            "light": str,
            "dark": str
        }
    )

    Config = TypedDict(
        "Config",
            {
            "label": NotRequired[ComponentType],
            "icon": NotRequired[typing.Any],
            "color": NotRequired[typing.Union[str]],
            "theme": NotRequired[typing.Union["ConfigTheme"]]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        className: typing.Optional[typing.Union[str]] = None,
        config: typing.Optional[typing.Dict[typing.Union[str, float, int], "Config"]] = None,
        ref: typing.Optional[typing.Union[str, typing.Any]] = None,
        key: typing.Optional[typing.Union[str, NumberType]] = None,
        **kwargs
    ):
        self._prop_names = ['children', 'id', 'className', 'config', 'key', 'ref']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'config', 'key', 'ref']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['config']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        if 'children' not in _explicit_args:
            raise TypeError('Required argument children was not specified.')

        super(ChartContainer, self).__init__(children=children, **args)

setattr(ChartContainer, "__init__", _explicitize_args(ChartContainer.__init__))



import json
from pathlib import Path

from setuptools import setup

# Read metadata from package-info.json
package_json = json.loads(
    (Path(__file__).parent / "dashkit_shadcn" / "package-info.json").read_text()
)

setup(
    name="dashkit_shadcn",
    version="1.0.1",
    description="Shadcn/ui-inspired chart components for Dash with native theming support",
    long_description=(Path(__file__).parent / "README.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    url="https://pypi.org/project/dashkit_shadcn/",
    project_urls={
        "Homepage": "https://pypi.org/project/dashkit_shadcn/",
        "Source": "https://github.com/iamgp/dash-attio",
        "Issues": "https://github.com/iamgp/dash-attio/issues",
    },
    packages=["dashkit_shadcn"],
    include_package_data=True,
    package_data={
        "dashkit_shadcn": [
            "*.js",
            "*.js.map",
            "*.json",
            "*.txt",
            "*.py",
        ]
    },
    python_requires=">=3.8",
    install_requires=[
        "dash>=2.0.0",
    ],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Framework :: Dash",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: User Interfaces",
    ],
    author="Dashkit Team",
    license="MIT",
    license_files=["LICENSE"],
)


# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class BarChart(Component):
    """A BarChart component.
BarChart renders a bar chart using shadcn/ui styling and Recharts.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Children components.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Custom CSS class for the container.

- config (dict; optional):
    Chart configuration object with data key mappings and colors.

- data (list of dicts; optional):
    Array of data points for the chart.

- dataKey (string; default 'value'):
    The key in data objects to use for the bar values.

- maxBarSize (number; optional):
    Maximum bar size.

- radius (number; default 4):
    Border radius for the bars.

- setProps (optional):
    Callback used by Dash to push prop changes from the client.

- showGrid (boolean | number | string | dict | list; default True):
    Whether to show the grid.

- showLegend (boolean | number | string | dict | list; default False):
    Whether to show the legend.

- showTooltip (boolean | number | string | dict | list; default True):
    Whether to show tooltips.

- showXAxis (boolean | number | string | dict | list; default True):
    Whether to show the x-axis.

- showYAxis (boolean | number | string | dict | list; default False):
    Whether to show the y-axis.

- stackId (string; optional):
    Stack ID for stacked bars.

- xAxisKey (string; default 'name'):
    The key in data objects to use for x-axis labels.

- yAxisKey (string; optional):
    The key in data objects to use for y-axis labels."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dashkit_shadcn'
    _type = 'BarChart'


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        className: typing.Optional[typing.Union[str]] = None,
        config: typing.Optional[typing.Union[dict]] = None,
        data: typing.Optional[typing.Union[typing.Sequence[dict]]] = None,
        dataKey: typing.Optional[typing.Union[str]] = None,
        xAxisKey: typing.Optional[typing.Union[str]] = None,
        yAxisKey: typing.Optional[typing.Union[str]] = None,
        showXAxis: typing.Optional[typing.Any] = None,
        showYAxis: typing.Optional[typing.Any] = None,
        showGrid: typing.Optional[typing.Any] = None,
        showTooltip: typing.Optional[typing.Any] = None,
        showLegend: typing.Optional[typing.Any] = None,
        stackId: typing.Optional[typing.Union[str]] = None,
        radius: typing.Optional[typing.Union[NumberType]] = None,
        maxBarSize: typing.Optional[typing.Union[NumberType]] = None,
        style: typing.Optional[typing.Any] = None,
        **kwargs
    ):
        self._prop_names = ['children', 'id', 'className', 'config', 'data', 'dataKey', 'maxBarSize', 'radius', 'setProps', 'showGrid', 'showLegend', 'showTooltip', 'showXAxis', 'showYAxis', 'stackId', 'style', 'xAxisKey', 'yAxisKey']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'config', 'data', 'dataKey', 'maxBarSize', 'radius', 'setProps', 'showGrid', 'showLegend', 'showTooltip', 'showXAxis', 'showYAxis', 'stackId', 'style', 'xAxisKey', 'yAxisKey']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(BarChart, self).__init__(children=children, **args)

setattr(BarChart, "__init__", _explicitize_args(BarChart.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class ChartTooltip(Component):
    """A ChartTooltip component.


Keyword arguments:

- key (string | number; optional)

- ref (string; optional):
    Allows getting a ref to the component instance. Once the component
    unmounts, React will set `ref.current` to `None` (or call the ref
    with `None` if you passed a callback ref). @,see,,{@link
    ,https://react.dev/learn/referencing-values-with-refs#refs-and-the-dom
    React Docs,}."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dashkit_shadcn'
    _type = 'ChartTooltip'


    def __init__(
        self,
        ref: typing.Optional[typing.Union[str, typing.Any]] = None,
        key: typing.Optional[typing.Union[str, NumberType]] = None,
        **kwargs
    ):
        self._prop_names = ['key', 'ref']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['key', 'ref']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(ChartTooltip, self).__init__(**args)

setattr(ChartTooltip, "__init__", _explicitize_args(ChartTooltip.__init__))
